==> railway-0.1.4.tgz: package/lib/railway_utils.js <==
var undef, sys = require('sys'),
    Script      = require('vm').Script;

exports.html_tag_params = function (params, override) {
    var maybe_params = '';
    safe_merge(params, override);
    for (var key in params) {
        if (params[key] != undef) {
            maybe_params += ' ' + key + '="' + params[key].toString().replace(/&/g, '&amp;').replace(/"/g, '&quot;') + '"';
        }
    }
    return maybe_params;
};

var safe_merge = exports.safe_merge = function (merge_what) {
    merge_what = merge_what || {};
    Array.prototype.slice.call(arguments).forEach(function (merge_with, i) {
        if (i == 0) return;
        for (var key in merge_with) {
            if (!merge_with.hasOwnProperty(key) || key in merge_what) continue;
            merge_what[key] = merge_with[key];
        }
    });
    return merge_what;
};

exports.humanize = function (underscored) {
    var res = underscored.replace(/_/g, ' ');
    return res[0].toUpperCase() + res.substr(1);
};

exports.camelize = function (underscored, upcaseFirstLetter) {
    var res = '';
    underscored.split('_').forEach(function (part) {
        res += part[0].toUpperCase() + part.substr(1);
    });
    return upcaseFirstLetter ? res : res[0].toLowerCase() + res.substr(1);
};

exports.classify = function (str) {
    return exports.camelize(exports.singularize(str));
};

exports.underscore = function (camelCaseStr) {
    return camelCaseStr
        .replace(/([a-z]+)([A-Z][a-z])/g, '\1_\2')
        .toLowerCase();
};

exports.singularize = require('../vendor/inflection.js').singularize,
exports.pluralize   = require('../vendor/inflection.js').pluralize;

// Stylize a string
function stylize(str, style) {
    var styles = {
        'bold'      : [1,  22],
        'italic'    : [3,  23],
        'underline' : [4,  24],
        'cyan'      : [96, 39],
        'blue'      : [34, 39],
        'yellow'    : [33, 39],
        'green'     : [32, 39],
        'red'       : [31, 39],
        'grey'      : [90, 39],
        'green-hi'  : [92, 32],
    };
    return '\033[' + styles[style][0] + 'm' + str +
           '\033[' + styles[style][1] + 'm';
};

var $ = function (str) {
    str = new(String)(str);

    ['bold', 'grey', 'yellow', 'red', 'green', 'cyan', 'blue', 'italic', 'underline'].forEach(function (style) {
        Object.defineProperty(str, style, {
            get: function () {
                return $(stylize(this, style));
            }
        });
    });
    return str;
};
stylize.$ = $;
exports.stylize = stylize;

exports.debug = function () {
    if (!app.settings.quiet) {
        sys.puts(Array.prototype.join.call(arguments, ' '));
    }
};

var addCoverage = exports.addCoverage = function (code, filename) {
    if (!process.cov) {
        //if (require('fulljslint').jslint(code)) {
        //}
        return code;
    }
    var lines = code.split('\n');

    if (lines.length > 0) {
        lines[0] = 'if (!__cov["' + filename + '"]) {__cov["' + filename + '"] = { 0: true}; }' + lines[0];
    }

    for (var i = 0; i < lines.length; i++) {
        var covLine = ' __cov["' + filename + '"][' + i + '] = true;';
        lines[i] = lines[i]
        .replace(/;$/, ';' + covLine)
        .replace(/^\s*(return|throw|break|continue)/, covLine + ' $1');
    }

    return lines.join('\n');
};

var cache = {};
function runCode (filename, context) {
    // extend context
    context.require = context.require || require;
    context.app = app;
    context.console = console;
    context.setTimeout = setTimeout;
    context.process = process;
    context.t = context.t || t;
    context.Buffer = Buffer;

    cache[filename] = cache[filename] || require('fs').readFileSync(filename);
    var code = cache[filename].toString();
    if (filename.match(/coffee$/)) {
        try {
            var cs = require('coffee-script');
        } catch (e) {
            throw new Error('Please install coffee-script npm package: `npm install coffee-script`');
        }
        try {
            code = require('coffee-script').compile(code);
        } catch (e) {
            console.log('Error in coffee code compilation in file ' + filename);
            throw e;
        }
    } else {
        code = addCoverage(code, filename);
    }
    try {
        var m = new Script(code.toString('utf-8'), filename);
        m.runInNewContext(context);
    } catch (e) {
        console.log('Error while executing ' + filename);
        throw e;
    }

    // disable caching in development mode
    if (app.disabled('eval cache')) {
        cache[filename] = false;
    }
}
exports.runCode = runCode;

==> railway-0.1.7-6.tgz: package/lib/railway_utils.js <==
var undef, sys = require('sys'),
    path = require('path'),
    Script      = require('vm').Script;

exports.html_tag_params = function (params, override) {
    var maybe_params = '';
    safe_merge(params, override);
    for (var key in params) {
        if (params[key] != undef) {
            maybe_params += ' ' + key + '="' + params[key].toString().replace(/&/g, '&amp;').replace(/"/g, '&quot;') + '"';
        }
    }
    return maybe_params;
};

var safe_merge = exports.safe_merge = function (merge_what) {
    merge_what = merge_what || {};
    Array.prototype.slice.call(arguments).forEach(function (merge_with, i) {
        if (i == 0) return;
        for (var key in merge_with) {
            if (!merge_with.hasOwnProperty(key) || key in merge_what) continue;
            merge_what[key] = merge_with[key];
        }
    });
    return merge_what;
};

exports.humanize = function (underscored) {
    var res = underscored.replace(/_/g, ' ');
    return res[0].toUpperCase() + res.substr(1);
};

exports.camelize = function (underscored, upcaseFirstLetter) {
    var res = '';
    underscored.split('_').forEach(function (part) {
        res += part[0].toUpperCase() + part.substr(1);
    });
    return upcaseFirstLetter ? res : res[0].toLowerCase() + res.substr(1);
};

exports.classify = function (str) {
    return exports.camelize(exports.singularize(str));
};

exports.underscore = function (camelCaseStr) {
    return camelCaseStr
        .replace(/([a-z]+)([A-Z][a-z])/g, '\1_\2')
        .toLowerCase();
};

exports.singularize = require('../vendor/inflection.js').singularize,
exports.pluralize   = require('../vendor/inflection.js').pluralize;

// Stylize a string
function stylize(str, style) {
    var styles = {
        'bold'      : [1,  22],
        'italic'    : [3,  23],
        'underline' : [4,  24],
        'cyan'      : [96, 39],
        'blue'      : [34, 39],
        'yellow'    : [33, 39],
        'green'     : [32, 39],
        'red'       : [31, 39],
        'grey'      : [90, 39],
        'green-hi'  : [92, 32],
    };
    return '\033[' + styles[style][0] + 'm' + str +
           '\033[' + styles[style][1] + 'm';
};

var $ = function (str) {
    str = new(String)(str);

    ['bold', 'grey', 'yellow', 'red', 'green', 'cyan', 'blue', 'italic', 'underline'].forEach(function (style) {
        Object.defineProperty(str, style, {
            get: function () {
                return $(stylize(this, style));
            }
        });
    });
    return str;
};
stylize.$ = $;
exports.stylize = stylize;

exports.debug = function () {
    railway.logger.write(Array.prototype.join.call(arguments, ' '));
};

var addCoverage = exports.addCoverage = function (code, filename) {
    if (!process.cov) {
        //if (require('fulljslint').jslint(code)) {
        //}
        return code;
    }
    var lines = code.split('\n');

    if (lines.length > 0) {
        lines[0] = 'if (!__cov["' + filename + '"]) {__cov["' + filename + '"] = { 0: true}; }' + lines[0];
    }

    for (var i = 0; i < lines.length; i++) {
        var covLine = ' __cov["' + filename + '"][' + i + '] = true;';
        lines[i] = lines[i]
        .replace(/;$/, ';' + covLine)
        .replace(/^\s*(return|throw|break|continue)/, covLine + ' $1');
    }

    return lines.join('\n');
};

var cache = {};
function runCode (filename, context) {
    // extend context
    context.require = context.require || require;
    context.app = app;
    context.console = console;
    context.setTimeout = setTimeout;
    context.process = process;
    context.t = context.t || t;
    context.Buffer = Buffer;

    cache[filename] = cache[filename] || filename && path.existsSync(filename) && require('fs').readFileSync(filename);
    if (!cache[filename]) {
        return;
    }
    var code = cache[filename].toString();
    if (filename.match(/coffee$/)) {
        try {
            var cs = require('coffee-script');
        } catch (e) {
            throw new Error('Please install coffee-script npm package: `npm install coffee-script`');
        }
        try {
            code = require('coffee-script').compile(code);
        } catch (e) {
            console.log('Error in coffee code compilation in file ' + filename);
            throw e;
        }
    } else {
        code = addCoverage(code, filename);
    }
    try {
        var m = new Script(code.toString('utf8'), filename);
        m.runInNewContext(context);
    } catch (e) {
        console.log('Error while executing ' + filename);
        throw e;
    }

    // disable caching in development mode
    if (app.disabled('eval cache')) {
        cache[filename] = false;
    }
}
exports.runCode = runCode;

function addSpaces (str, len, to_start) {
    var str_len = str.length;
    for (var i = str_len; i < len; i += 1) {
        if (!to_start) {
            str += ' ';
        } else {
            str = ' ' + str;
        }
    }
    return str;
}
exports.addSpaces = addSpaces;
